# django-power-extensions

Collections of django extensions.

## Collections

### python libraries

- ipython>=7.13.0
- mysqlclient>=1.4.6
- bizerror>=0.2.3
- fastutils>=0.9.0
- requests>=2.23.0
- PyYAML>=5.3
- redis>=3.4.1
- pillow>=7.0.0
- croniter>=0.3.31

### django

- django~=2.2.0
- django-click>=2.1.0
- django-apiview>=0.2.0 
- django-redis-cache>=2.1.0
- django-simple-tags>=0.3.0

### django hacks

- django-checkbox-normalize>=0.1.0
- django-fullname-localization>=0.1.0

### static libraries

- django-static-jquery3>=3.3.1.1
- django-static-jquery-ui>=1.12.1.0
- django-static-fontawesome>=5.12.1.4
- django-static-ionicons>=2.0.1.2
- django-static-bootstrap>=3.3.7.1
- django-static-respond>=1.4.2.1
- django-static-html5shiv>=3.7.3.2
- django-static-echarts>=4.0.4.1
- django-static-adminlte>=2.4.3.2

### django widgets

- django-simple-captcha>=0.5.12
- django-yearmonth-widget>=0.1.0
- django-secure-password-input>=0.1.0
- django-toggle-switch-widget>=0.1.0
- django-cascading-dropdown-widget>=0.1.0
- django-ckeditor>=5.9.0

### django middlewares

- django-middleware-global-request>=0.2.0

### django model extentions

- django-mptt>=0.11.0
- django-dataperm-model>=0.1.0
- django-admin-item-owner>=0.2.0

### django admin extentions

- django-import-export>=2.0.2
- django-modeladmin-reorder>=0.3.1
- django-msms-admin>=0.1.1
- django-readedit-switch-admin>=0.4.2
- django-changelist-toolbar-admin>=0.2.0
- django-cards-admin>=0.1.0
- django-admin-fix-ie-compatible>=0.1.0
- django-admin-safe-login>=0.2.0
- django-force-disable-permissions-admin>=0.2.0
- django-with-extra-context-admin>=0.1.0
- django-dynamic-resource-admin>=0.1.0

### Simple system

- django-redis-counter>=0.1.1

### Complex system

- django-power-cms>=0.2.0

## Releases

### v0.1.0 2020/03/16

1. First release.